# TC Data Tools

Package to reuse and simplify common tasks for developing data products and machine learning models as:
- Connect and extract data from databases
- IO functions to datalake
- Machine learning tasks
